function [mu] = Genmu(U,r,Upsilon,mu0)

%%Version 1.0
%Copyright 28 December 2012 by Alan R. Parry
%Permission is granted to all to use this software for non-commercial uses
%only. Permission for commercial use must be obtained in writing from the
%author.
%
%This function generates the energy density function "mu" corresponding to
%"Upsilon", "mu0", and the functions in the matrix "U" all defined on the
%mesh "r".  U is a 5 row matrix containing the values of the functions f
%(row 1), p (row 2), V (row 3), M (row 4), and muV (row 5).  The functions,
%f, p, V, and M are as defined in the paper, muV is equal to 4pi r^2 mu,
%where mu is the energy density.

%Compute parameters.

N = length(r) - 1;

%Retrieve functions.

f = U(1,1:N+1);
p = U(2,1:N+1);
muV = U(5,1:N+1);

%Define mu.

mu = zeros(1,N+1);

%Compute values of mu.

mu(1) = mu0*(abs(f(1))^2 + abs(p(1))^2/Upsilon^2);

for k=2:N+1
    
    mu(k) = muV(k)/(4*pi*r(k)^2);
    
end

end